<?php

namespace Shopping\Returning\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Shopping\Returning\Interfaces\ReasonRepositoryInterface;

class ReasonPublicController extends BaseController
{
    // use ReasonWorkflow;

    /**
     * Constructor.
     *
     * @param type \Shopping\Reason\Interfaces\ReasonRepositoryInterface $reason
     *
     * @return type
     */
    public function __construct(ReasonRepositoryInterface $reason)
    {
        $this->repository = $reason;
        parent::__construct();
    }

    /**
     * Show reason's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $reasons = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$returning::$reason.names'))
            ->view('$returning::public.reason.index')
            ->data(compact('$reasons'))
            ->output();
    }

    /**
     * Show reason's list based on a type.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function list($type = null)
    {
        $reasons = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$returning::$reason.names'))
            ->view('$returning::public.reason.index')
            ->data(compact('$reasons'))
            ->output();
    }

    /**
     * Show reason.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $reason = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->title($$reason->name . trans('$returning::$reason.name'))
            ->view('$returning::public.reason.show')
            ->data(compact('$reason'))
            ->output();
    }

}
