<?php

namespace Shopping\Returning\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Shopping\Returning\Interfaces\ReturningRepositoryInterface;

class ReturningPublicController extends BaseController
{
    // use ReturningWorkflow;

    /**
     * Constructor.
     *
     * @param type \Shopping\Returning\Interfaces\ReturningRepositoryInterface $returning
     *
     * @return type
     */
    public function __construct(ReturningRepositoryInterface $returning)
    {
        $this->repository = $returning;
        parent::__construct();
    }

    /**
     * Show returning's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $returnings = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$returning::$returning.names'))
            ->view('$returning::public.returning.index')
            ->data(compact('$returnings'))
            ->output();
    }

    /**
     * Show returning's list based on a type.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function list($type = null)
    {
        $returnings = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$returning::$returning.names'))
            ->view('$returning::public.returning.index')
            ->data(compact('$returnings'))
            ->output();
    }

    /**
     * Show returning.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $returning = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->title($$returning->name . trans('$returning::$returning.name'))
            ->view('$returning::public.returning.show')
            ->data(compact('$returning'))
            ->output();
    }

}
