<?php

namespace Shopping\Returning\Providers;

use Illuminate\Support\ServiceProvider;

class ReturningServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'returning');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'returning');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('shopping.returning', function ($app) {
            return $this->app->make('Shopping\Returning\Returning');
        });

        // Bind Returning to repository
        $this->app->bind(
            'Shopping\Returning\Interfaces\ReturningRepositoryInterface',
            \Shopping\Returning\Repositories\Eloquent\ReturningRepository::class
        );
        // Bind Reason to repository
        $this->app->bind(
            'Shopping\Returning\Interfaces\ReasonRepositoryInterface',
            \Shopping\Returning\Repositories\Eloquent\ReasonRepository::class
        );

        $this->app->register(\Shopping\Returning\Providers\AuthServiceProvider::class);
                $this->app->register(\Shopping\Returning\Providers\EventServiceProvider::class);
        
        $this->app->register(\Shopping\Returning\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['shopping.returning'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('shopping/returning.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/returning')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/returning')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
